
# q-expansion of newform 576.4.f.b, downloaded from the LMFDB on 03 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 576
weight = 4
poly_data = [65536, 0, 0, 0, -12544, 0, 0, 0, 2145, 0, 0, 0, -49, 0, 0, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[340096, 0, 0, 0, -105105, 0, 0, 0, 2145, 0, 0, 0, -49, 0, 0, 0], 68640], [[640136, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 0, 0, 0], 6435], [[-6272, 0, 0, 0, 1889, 0, 0, 0, -49, 0, 0, 0, 1, 0, 0, 0], 192], [[0, 413952, 0, 615568, 0, -70785, 0, 0, 0, -32175, 0, 0, 0, -33, 0, -112], 3294720], [[0, -2922752, 0, 1041680, 0, 499785, 0, 0, 0, -12441, 0, 0, 0, 233, 0, 16], 439296], [[0, 0, -2097664, 0, 0, 0, 190385, 0, 0, 0, -4225, 0, 0, 0, 81, 0], 599040], [[0, 220862208, 0, -80588272, 0, -37767015, 0, 0, 0, 804375, 0, 0, 0, -17607, 0, -752], 6589440], [[0, 175779072, 0, 63116368, 0, -30057885, 0, 0, 0, 714285, 0, 0, 0, -14013, 0, 848], 3294720], [[0, 179349504, 0, 108197504, 0, 40171560, 0, -33032285, 0, -909480, 0, 760045, 0, 22824, 0, -16381], 52715520], [[0, -33331200, 0, -21183872, 0, -7958808, 0, 6416267, 0, 216216, 0, -158587, 0, -6168, 0, 3307], 10543104], [[0, 0, 65536, 0, 0, 0, -96657, 0, 0, 0, 2145, 0, 0, 0, -49, 0], 76032], [[0, 0, 41353216, 0, 0, 0, -53691495, 0, 0, 0, 1353495, 0, 0, 0, -30919, 0], 39536640], [[0, -2217984, 0, 1372544, 0, -512600, 0, -417395, 0, 12760, 0, 9955, 0, -344, 0, -211], 337920], [[0, -272197632, 0, 162865792, 0, -60351720, 0, -49786165, 0, 1321320, 0, 1131845, 0, -32232, 0, -24533], 26357760], [[0, 0, -492032, 0, 0, 0, 44913, 0, 0, 0, -1089, 0, 0, 0, 17, 0], 5632]]

hecke_ring_character_values = [[127, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [325, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [65, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0], [0, -4, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 4, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -5, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -4, -5, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -4, -1, 0, 0, 0], [0, -17, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 2, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -42, 0, 0, 0, 0, 0, 0, 0, 0, -1], [0, 0, 0, 0, -2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 30, -17, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 19, -6, 0], [0, -61, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -25, 0, 0, 0, 0, 0, 0, 0, 0, 5], [0, 0, 0, 0, -13, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0], [-332, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 9, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 31, -5, 0], [0, 0, 0, 0, 0, 49, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0], [8, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -52, -37, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -8, 39, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 4, 0], [0, -96, 0, -21, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 19, 0, 14, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -11, -29, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 28, 26, 0], [0, 0, 0, 0, 0, 76, 0, -23, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 71, 0, 0, 0, 0, 0, 0, 0, 0, 9], [0, 0, 0, 0, 0, 0, 0, 0, 0, 117, 2, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -134, -71, 0, 0, 0], [0, -15, 0, 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -64, 0, 0, 0, 0, 0, 0, 0, 0, 1], [0, 0, 0, 0, -73, 0, 0, 0, -35, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 105, 38, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -51, -44, 0], [0, -8, 0, -11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 69, 0, 0, 0, -9, 0, 0, 0, 0, 0, 0, 0], [1142, 0, -8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 94, 85, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -79, 59, 0, 0, 0], [0, 0, 0, 0, 0, 0, 157, 0, 0, 0, 0, 0, 0, 0, 0, -19], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 293, 3, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -143, -39, 0], [0, 456, 0, -29, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -153, 0, 22, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 51, 0, 0, 0, -61, 0, 0, 0, 0, 0, 0, 0], [2620, 0, 27, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -78, 105, 0], [0, 0, 0, 0, 0, -209, 0, -40, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -42, 0, 0, 0, 20, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 170, 115, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 241, 31, 0, 0, 0], [0, 528, 0, 93, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -297, 0, 48, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 492, 0, 0, 0, 0, 0, 0, 0, 0, -2], [0, 0, 0, 0, 0, 0, 0, 0, 0, 306, 99, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 135, 0, 0, 0, 0, 0, 0, 0, 0, 47], [0, 0, 0, 0, -30, 0, 0, 0, 52, 0, 0, 0, 0, 0, 0, 0], [1198, 0, -52, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 396, 137, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 671, 0, 0, 0, 0, 0, 0, 0, 0, 5], [-2764, 0, -60, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -89, -125, 0], [0, 163, 0, 100, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -337, 0, 34, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -133, 0, 0, 0, 24, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 455, -25, 0, 0, 0], [0, 373, 0, -128, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1549, 0, 0, 0, 0, 0, 0, 0, 0, -6], [0, 0, 0, 0, 119, 0, 0, 0, 15, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 221, -186, 0, 0, 0, 0, 0], [0, -1221, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 434, 0, 69, 0, 0, 0, 0, 0, 0, 0, 0], [2800, 0, 59, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 277, 27, 0], [0, 404, 0, -119, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 136, 0, 0, 0, 83, 0, 0, 0, 0, 0, 0, 0], [-11126, 0, 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 281, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 213, -87, 0], [0, 0, 0, 0, 0, 12, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [-3800, 0, -139, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 685, -276, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 115, 85, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 29, -299, 0], [0, 0, 0, 0, -201, 0, 0, 0, -170, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -802, 51, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 257, -160, 0], [0, 0, 0, 0, 0, 0, 144, 0, 0, 0, 0, 0, 0, 0, 0, 72], [0, 0, 0, 0, -293, 0, 0, 0, -56, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 926, -343, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 678, 0, -73, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -2527, 0, 0, 0, 0, 0, 0, 0, 0, 34], [0, -2116, 0, -229, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1334, 0, 0, 0, 0, 0, 0, 0, 0, 13], [0, 0, 0, 0, 0, 0, 0, 0, 0, 259, -30, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 200, 77, 0], [0, 0, 0, 0, 0, -614, 0, 207, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 766, 0, 0, 0, 0, 0, 0, 0, 0, 58], [-1754, 0, -48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 214, 0], [0, 0, 0, 0, 0, 1233, 0, 14, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -142, 0, 0, 0, -25, 0, 0, 0, 0, 0, 0, 0], [3998, 0, -80, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 494, 483, 0, 0, 0], [0, -2239, 0, -220, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -37, 0, 132, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1474, 0, 0, 0, 0, 0, 0, 0, 0, 4], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -575, 199, 0, 0, 0], [0, 0, 0, 0, 0, -840, 0, -105, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 612, 0, 0, 0, 0, 0, 0, 0, 0, 13], [0, 0, 0, 0, 484, 0, 0, 0, 183, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -197, 76, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 131, -110, 0], [0, 407, 0, 520, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [20638, 0, 44, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -509, 614, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -7, 69, 0], [0, 0, 0, 0, 0, 0, 1740, 0, 0, 0, 0, 0, 0, 0, 0, -63], [0, 0, 0, 0, 0, 0, 0, 0, 0, 1982, 293, 0, 0, 0, 0, 0], [0, 1652, 0, 271, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -141, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1528, 223, 0, 0, 0], [0, 1380, 0, 413, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -3306, 0, 0, 0, 0, 0, 0, 0, 0, 2], [0, 0, 0, 0, -41, 0, 0, 0, -255, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -838, -361, 0, 0, 0], [0, 488, 0, -501, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -1456, 0, -9, 0, 0, 0, 0, 0, 0, 0, 0], [8954, 0, -236, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -740, 533, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 4777, 0, 0, 0, 0, 0, 0, 0, 0, -24], [0, 0, 0, 0, 0, 0, 0, 0, 0, -809, 844, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 384, 0, 219, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1725, 0, 0, 0, 0, 0, 0, 0, 0, 6], [0, 0, 0, 0, 0, 0, 0, 0, 0, 1146, 621, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1552, -11, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -500, 834, 0], [0, -32, 0, -757, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 571, 0, 0, 0, 188, 0, 0, 0, 0, 0, 0, 0], [0, 3427, 0, -544, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -1914, 0, -103, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -494, 0, 0, 0, 0, 0, 0, 0, 0, -169], [0, 0, 0, 0, -465, 0, 0, 0, -223, 0, 0, 0, 0, 0, 0, 0], [0, 4591, 0, -180, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 551, 0, 320, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -2038, 0, 0, 0, 0, 0, 0, 0, 0, 79], [0, 0, 0, 0, 346, 0, 0, 0, -420, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 2246, 0, 0, 0, 0, 0, 0, 0, 0, -133], [0, 0, 0, 0, -477, 0, 0, 0, 37, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1493, -851, 0, 0, 0], [0, 0, 0, 0, 0, -1010, 0, -303, 0, 0, 0, 0, 0, 0, 0, 0], [-18494, 0, -112, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 2145, 592, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -847, 226, 0], [0, 0, 0, 0, 0, 394, 0, -565, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2267, -397, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -295, -979, 0], [0, 0, 0, 0, 0, 1926, 0, 227, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 746, 0, 0, 0, 340, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 824, 1991, 0, 0, 0], [0, 3501, 0, 680, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]
